@@ -61,7 +61,7 @@
 #define MINVERSION 0 /* API compatible, ABI may change, functional
 		      * enhancements only, consumer can be left unchanged if
 		      * enhancements are not considered */
-#define PATCHLEVEL 0 /* API / ABI compatible, no functional changes, no
+#define PATCHLEVEL 1 /* API / ABI compatible, no functional changes, no
 		      * enhancements, bug fixes only */
 
 static int Verbosity = 0;
@@ -74,10 +74,10 @@ struct kernel_rng {
 };
 
 static struct kernel_rng Random = {
-	.fd = 0,
-	.ec = NULL,
-	.rpi = NULL,
-	.dev = "/dev/random"
+	/*.fd = */ 0,
+	/*.ec = */ NULL,
+	/*.rpi = */ NULL,
+	/*.dev = */ "/dev/random"
 };
 
 /*
@@ -104,10 +104,10 @@ static void install_alarm(void);
 static void dealloc(void);
 static void dealloc_rng(struct kernel_rng *rng);
 
-void jentrng_versionstring(char *buf, size_t buflen)
+static void jentrng_versionstring(char *buf, size_t buflen)
 {
-	snprintf(buf, buflen, "jitterentropy-rngd %d.%d.%d", MAJVERSION, MINVERSION,
-		 PATCHLEVEL);
+	snprintf(buf, buflen, "jitterentropy-rngd %d.%d.%d",
+		 MAJVERSION, MINVERSION, PATCHLEVEL);
 }
 
 static void usage(void)
@@ -201,23 +201,24 @@ static void dolog(int severity, const char *fmt, ...)
 static size_t write_random(struct kernel_rng *rng, char *buf, size_t len)
 {
 	size_t written = 0;
-	rng->rpi->entropy_count = (RNDBYTES * 8); /* value is in bits */
-	rng->rpi->buf_size = RNDBYTES;
-	memcpy(rng->rpi->buf, buf, RNDBYTES);
-	memset(buf, 0, RNDBYTES);
 	int ret;
 
+	rng->rpi->entropy_count = (len * 8); /* value is in bits */
+	rng->rpi->buf_size = len;
+	memcpy(rng->rpi->buf, buf, len);
+	memset(buf, 0, len);
+
 	ret =  ioctl(rng->fd, RNDADDENTROPY, rng->rpi);
 	if (0 > ret)
-		dolog(LOG_WARN, "Error injecting entropy: %s", strerror(ret));
+		dolog(LOG_WARN, "Error injecting entropy: %s", strerror(errno));
 	else {
-		dolog(LOG_DEBUG, "Injected %d bytes of entropy", RNDBYTES);
-		written = RNDBYTES;
+		dolog(LOG_DEBUG, "Injected %d bytes of entropy", len);
+		written = len;
 	}
 
 	rng->rpi->entropy_count = 0;
 	rng->rpi->buf_size = 0;
-	memset(rng->rpi->buf, 0, RNDBYTES);
+	memset(rng->rpi->buf, 0, len);
 
 	return written;
 }
@@ -280,6 +281,8 @@ static void sig_entropy_avail(int sig)
 	int entropy = 0;
 	size_t written = 0;
 
+	(void)sig;
+
 	dolog(LOG_VERBOSE, "Wakeup call for alarm on %s", ENTROPYAVAIL);
 	entropy = read_entropy_avail(Entropy_avail_fd);
 
@@ -300,6 +303,7 @@ out:
 /* terminate the daemon cleanly */
 static void sig_term(int sig)
 {
+	(void)sig;
 	dolog(LOG_DEBUG, "Shutting down cleanly\n");
 	dealloc();
 	exit(0);
@@ -446,7 +450,8 @@ static void create_pid_file(const char *pid_file)
 
 	/* write our pid to the pid file */
 	snprintf(pid_str, sizeof(pid_str), "%d\n", getpid());
-	if (write(Pidfile_fd, pid_str, strlen(pid_str)) != strlen(pid_str)) {
+	if (write(Pidfile_fd, pid_str, strlen(pid_str)) !=
+	    (ssize_t)strlen(pid_str)) {
 		dolog(LOG_ERR, "Cannot write to pid file\n");
 		exit(1);
 	}
